Django Cast
===========

Welcome to the Django Cast documentation! Django Cast is blogging / podcasting
package for Django based on `Wagtail <https://wagtail.org/>`_.

This documentation is still in development and there are a lot of blanks to
fill since Django Cast switched to Wagtail.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   contributing
   releases/index
